pub trait MultilinearExtensionWithConfig<F: PrimeField> {
// Required methods
fn fix_variables_with_config(
&mut self,
partial_point: &[F],
config: &F::Config,
);
fn fixed_variables_with_config(
&self,
partial_point: &[F],
config: &F::Config,
) -> Self;
fn evaluate_with_config(
self,
point: &[F],
config: &F::Config,
) -> Result<F, EvaluationError>;
}Expand description
This trait allows to evaluate
multilinear extension types that store
F::Inner Montgomery representations
instead of field elements F which are typically
an F::Inner and the field config.
Required Methods
Sourcefn fix_variables_with_config(&mut self, partial_point: &[F], config: &F::Config)
fn fix_variables_with_config(&mut self, partial_point: &[F], config: &F::Config)
Reduce the number of variables of self by fixing the
partial_point.len() variables at partial_point.
Sourcefn fixed_variables_with_config(
&self,
partial_point: &[F],
config: &F::Config,
) -> Self
fn fixed_variables_with_config( &self, partial_point: &[F], config: &F::Config, ) -> Self
Creates a new object with the number of variables of self reduced by
fixing the partial_point.len() variables at partial_point.
Sourcefn evaluate_with_config(
self,
point: &[F],
config: &F::Config,
) -> Result<F, EvaluationError>
fn evaluate_with_config( self, point: &[F], config: &F::Config, ) -> Result<F, EvaluationError>
Evaluate the MLE in full. Asserts that the point.len()
is equal the self.num_vars.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.